<!-- SPDX-FileCopyrightText: 2026 PythonWoods <dev@pythonwoods.dev> -->
<!-- SPDX-License-Identifier: Apache-2.0 -->

# Hidden Page

TRAP: This page exists on disk but is NOT listed in the nav.

When a nav is declared, MkDocs will not serve this page.
Any link pointing here resolves to a valid file but produces a virtual 404.

Zenzic rc4 should emit: UNREACHABLE_LINK
